@@ -105,7 +105,7 @@ class Context:
         var = self.parent_context.var if name in self.global_var and self.parent_context is not None else self.var
         if name in var:
             if (size != var[name] or
-                name in ATranspiler.PREDEFINED_VARIABLES and size != ATranspiler.PREDEFINED_VARIABLES[name]):
+                name in self.global_var and name in ATranspiler.PREDEFINED_VARIABLES and size != ATranspiler.PREDEFINED_VARIABLES[name]):
                 raise TranspilerError(f"incompatible sizes for list assignment to {name}", ast_node)
         else:
             var[name] = size
@@ -125,7 +125,7 @@ class Context:
         return "".join([
             f"var {self.var_str(name)}{f'[{self.var[name]}]' if self.var[name] is not None else ''}\n"
             for name in self.var
-            if name not in ATranspiler.PREDEFINED_VARIABLES
+            if self.parent_context is not None or name not in ATranspiler.PREDEFINED_VARIABLES
         ])
 
     def reset_tmp_req_current_expr(self):
@@ -688,6 +688,10 @@ end
 """
             code = context.tmp_var_str(tmp_offset)
             is_boolean = False
+        elif isinstance(node, ast.Index):
+            code, aux_st, is_boolean = self.compile_expr(node.value, context, self.PRI_NUMERIC)
+            aux_statements += aux_st
+            return code, aux_statements, False
         elif isinstance(node, ast.List):
             if priority_container > self.PRI_ASSIGN:
                 raise TranspilerError("list not supported in expression", node)
@@ -714,7 +718,7 @@ end
                 raise TranspilerError(f"unknown variable {name}", node)
             if var_array_size is None:
                 raise TranspilerError(f"indexing of variable {name} which is not a list", node)
-            index = node.slice.value
+            index = node.slice
             index_value, aux_st, is_index_boolean = self.compile_expr(index, context, self.PRI_NUMERIC)
             if is_index_boolean:
                 tmp_offset = context.request_tmp_expr()
@@ -777,7 +781,7 @@ end
         """
         index = None
         if isinstance(target, ast.Subscript):
-            index = target.slice.value
+            index = target.slice
             target = target.value
         name = self.decode_attr(target)
         return name, index
@@ -1102,9 +1106,15 @@ return
             context_top.functions[fun_name].freeze_return_type()
             # second pass to produce transpiled code with correct local variable names
             fun_output_src = self.compile_node_array(context_top.functions[fun_name].function_def.body, context_top.functions[fun_name])
-            function_src += f"""
-{"onevent" if context_top.functions[fun_name].is_onevent else "sub"} {fun_name}
-""" + fun_output_src
+            if context_top.functions[fun_name].is_onevent:
+                function_src += f"""
+onevent {fun_name.replace("_", ".")}
+"""
+            else:
+                function_src += f"""
+sub {fun_name}
+"""
+            function_src += fun_output_src
 
         # compile top-level code again, now that function return types are known
         self.output_src = self.compile_node_array(top_code, context_top) + function_src
@@ -1168,16 +1178,3 @@ return
         transpiler.transpile()
         output_src = transpiler.get_output()
         return output_src
-
-
-if __name__ == "__main__":
-
-    src = None
-    if len(sys.argv) >= 2:
-        with open(sys.argv[1]) as f:
-            src = f.read()
-    else:
-        src = sys.stdin.read()
-
-    output_src = ATranspiler.simple_transpile(src)
-    print(output_src)
